package org.eclipse.jdt.internal.compiler.apt.dispatch;

import org.eclipse.jdt.internal.compiler.ast.CompilationUnitDeclaration;
import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;
import org.eclipse.jdt.internal.compiler.env.ICompilationUnit;
import org.eclipse.jdt.internal.compiler.Compiler;
import java.util.ArrayList;
import java.util.List;
import java.io.PrintWriter;
import org.eclipse.jdt.internal.compiler.AbstractAnnotationProcessorManager;

public abstract class BaseAnnotationProcessorManager extends AbstractAnnotationProcessorManager implements IProcessorProvider
{
    protected PrintWriter _out;
    protected PrintWriter _err;
    protected BaseProcessingEnvImpl _processingEnv;
    protected boolean _isFirstRound;
    protected List<ProcessorInfo> _processors;
    protected boolean _printProcessorInfo;
    protected boolean _printRounds;
    protected int _round;
    
    public BaseAnnotationProcessorManager() {
        this._isFirstRound = true;
        this._processors = new ArrayList();
        this._printProcessorInfo = false;
        this._printRounds = false;
    }
    
    public void configure(Object batchCompiler, String[] options) {
        throw new UnsupportedOperationException();
    }
    
    public void configureFromPlatform(Compiler compiler, Object compilationUnitLocator, Object javaProject) {
        throw new UnsupportedOperationException();
    }
    
    public List<ProcessorInfo> getDiscoveredProcessors() {
        return this._processors;
    }
    
    public ICompilationUnit[] getDeletedUnits() {
        return this._processingEnv.getDeletedUnits();
    }
    
    public ICompilationUnit[] getNewUnits() {
        return this._processingEnv.getNewUnits();
    }
    
    public ReferenceBinding[] getNewClassFiles() {
        return this._processingEnv.getNewClassFiles();
    }
    
    public void reset() {
        this._processingEnv.reset();
    }
    
    public void setErr(PrintWriter err) {
        this._err = err;
    }
    
    public void setOut(PrintWriter out) {
        this._out = out;
    }
    
    public void setProcessors(Object[] processors) {
        throw new UnsupportedOperationException();
    }
    
    public void processAnnotations(CompilationUnitDeclaration[] units, ReferenceBinding[] referenceBindings, boolean isLastRound) {
        RoundEnvImpl roundEnv = new RoundEnvImpl(units, referenceBindings, isLastRound, this._processingEnv);
        if (this._isFirstRound) {
            this._isFirstRound = false;
        }
        PrintWriter traceProcessorInfo = this._printProcessorInfo ? this._out : null;
        PrintWriter traceRounds = this._printRounds ? this._out : null;
        if (traceRounds != null) {
            PrintWriter printWriter = traceRounds;
            StringBuilder sb = new StringBuilder("Round ");
            int n = this._round + 1;
            this._round = n;
            printWriter.println(sb.append(n).append(':').toString());
        }
        RoundDispatcher dispatcher = new RoundDispatcher(this, roundEnv, roundEnv.getRootAnnotations(), traceProcessorInfo, traceRounds);
        dispatcher.round();
    }
}
